View source: R/predictHeight.R
| predictHeight | R Documentation |
The function predicts height from diameter based on a fitted model. As the predict() function for brms models takes ~10 minutes to run, predictions are calculated using the coefficients from the models directly.
predictHeight(D, model, err = FALSE, plot = NULL)
D |
a n x m matrix containing tree diameters (in cm), where n is the number of trees and m is the number of Monte Carlo simulations (m = 1 if no error propagation). |
model |
The output of the |
err |
If |
plot |
(optional) Plot ID, must be either one value, or a vector of the same length as D. This argument is used to build stand-specific HD models. |
In the case where the error is FALSE and the model is a log-log model, we use the
Baskerville correction, a bias correction factor used to get unbiased backtransformation values.
Returns a vector of total tree height (in m).
Arthur BAILLY
minpack.lm::nlsLM()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.